import { MenuItem } from "electron";
import { Color } from "vs/base/common/color";
import { IMenuItem } from "./menuitem";
import { Disposable } from "vs/base/common/lifecycle";
import { Event } from "vs/base/common/event";
import { MenubarOptions } from "./types/menubar-options";
export declare const MENU_MNEMONIC_REGEX: RegExp;
export declare const MENU_ESCAPED_MNEMONIC_REGEX: RegExp;
export interface IMenuOptions {
    ariaLabel?: string;
    enableMnemonics?: boolean;
}
export interface IMenuStyle {
    foregroundColor?: Color;
    backgroundColor?: Color;
    selectionForegroundColor?: Color;
    selectionBackgroundColor?: Color;
    separatorColor?: Color;
}
interface ISubMenuData {
    parent: CETMenu;
    submenu?: CETMenu;
}
export declare class CETMenu extends Disposable {
    items: IMenuItem[];
    private focusedItem?;
    private menuContainer;
    private mnemonics;
    private menubarOptions?;
    private options;
    private closeSubMenu;
    private triggerKeys;
    parentData: ISubMenuData;
    private _onDidCancel;
    get onDidCancel(): Event<void>;
    constructor(container: HTMLElement, menubarOptions?: MenubarOptions, options?: IMenuOptions, closeSubMenu?: () => void);
    setAriaLabel(label: string): void;
    private isTriggerKeyEvent;
    private updateFocusedItem;
    getContainer(): HTMLElement;
    createMenu(items: MenuItem[] | undefined): void;
    focus(index?: number): void;
    focus(selectFirst?: boolean): void;
    private focusNext;
    private focusPrevious;
    private updateFocus;
    private doTrigger;
    private cancel;
    dispose(): void;
    style(style: IMenuStyle | undefined): void;
    private focusItemByElement;
    private setFocusedItem;
}
export declare function cleanMnemonic(label: string): string;
export {};
